import { EllipsisOutlined, PlusOutlined } from '@ant-design/icons';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import {
    ProTable, TableDropdown, PageContainer, ModalForm, ProForm,
    ProFormDateRangePicker,
    ProFormSelect,
    ProFormText,
} from '@ant-design/pro-components';
import { Button, Dropdown, Space, Tag, Form } from 'antd';
import { useRef } from 'react';
export const waitTimePromise = async (time: number = 100) => {
    return new Promise((resolve) => {
        setTimeout(() => {
            resolve(true);
        }, time);
    });
};

export const waitTime = async (time: number = 100) => {
    await waitTimePromise(time);
};

type GithubIssueItem = {
    url: string;
    id: number;
    number: number;
    title: string;
    labels: {
        name: string;
        color: string;
    }[];
    state: string;
    comments: number;
    created_at: string;
    updated_at: string;
    closed_at?: string;
};

const columns: ProColumns<GithubIssueItem>[] = [
    {
        dataIndex: 'index',
        valueType: 'indexBorder',
        width: 48,
    },
    {
        title: '标题',
        dataIndex: 'title',
        hideInSearch: true
    },
    {
        disable: true,
        title: '状态',
        dataIndex: 'state',
    },
    {
        disable: true,
        title: '标签',
        dataIndex: 'labels',
    },
    {
        title: '创建时间',
        key: 'showTime',
        dataIndex: 'created_at',
    },
    {
        title: '创建时间',
        dataIndex: 'created_at',
        valueType: 'dateRange',

    },
    {
        title: '操作',
        valueType: 'option',
        key: 'option',
        render: (text, record, _, action) => [
            <a
                key="editable"
                onClick={() => {
                    action?.startEditable?.(record.id);
                }}
            >
                编辑
            </a>,
            <a href={record.url} target="_blank" rel="noopener noreferrer" key="view">
                查看
            </a>,
            <TableDropdown
                key="actionGroup"
                onSelect={() => action?.reload()}
                menus={[
                    { key: 'copy', name: '复制' },
                    { key: 'delete', name: '删除' },
                ]}
            />,
        ],
    },
];

export default () => {
    const [form] = Form.useForm<{ name: string; company: string }>();
    return (
        <>
            <PageContainer>
                <ProTable

                    columns={columns}
                    pagination={{
                        pageSize: 5,
                        onChange: (page) => console.log(page),
                    }}
                    toolBarRender={() => [
                        <ModalForm<{
                            name: string;
                            company: string;
                        }>
                            title="新增百度接口"
                            trigger={
                                <Button type="primary">
                                    <PlusOutlined />
                                    新建表单
                                </Button>
                            }
                            submitter={{
                                render: (props, defaultDoms) => {
                                  return [
                                    <Button
                                      key="extra-reset"
                                      onClick={() => {
                                        props.reset();
                                      }}
                                    >
                                      重置
                                    </Button>,
                                    ...defaultDoms,

                                  ];
                                },
                              }}
                            form={form}
                            autoFocusFirstInput
                            modalProps={{
                                destroyOnClose: true,
                                onCancel: () => console.log('run'),
                            }}
                            submitTimeout={2000}
                            onFinish={async (values) => {
                                await waitTime(2000);
                                console.log(values.name);
                                return true;
                            }}
                        >
                            <ProForm.Group>
                                <ProFormText
                                    width="md"
                                    name="name"
                                    label="签约客户名称"
                                    tooltip="最长为 24 位"
                                    placeholder="请输入名称"
                                />

                                <ProFormText
                                    width="md"
                                    name="company"
                                    label="我方公司名称"
                                    placeholder="请输入名称"
                                />
                            </ProForm.Group>
                            <ProForm.Group>
                                <ProFormText
                                    width="md"
                                    name="contract"
                                    label="合同名称"
                                    placeholder="请输入名称"
                                />
                                <ProFormDateRangePicker name="contractTime" label="合同生效时间" />
                            </ProForm.Group>
                            <ProForm.Group>
                                <ProFormSelect
                                    request={async () => [
                                        {
                                            value: 'chapter',
                                            label: '盖章后生效',
                                        },
                                    ]}
                                    width="xs"
                                    name="useMode"
                                    label="合同约定生效方式"
                                />
                                <ProFormSelect
                                    width="xs"
                                    options={[
                                        {
                                            value: 'time',
                                            label: '履行完终止',
                                        },
                                    ]}
                                    name="unusedMode"
                                    label="合同约定失效效方式"
                                />
                            </ProForm.Group>
                            <ProFormText width="sm" name="id" label="主合同编号" />
                            <ProFormText
                                name="project"
                                disabled
                                label="项目名称"
                                initialValue="xxxx项目"
                            />
                            <ProFormText
                                width="xs"
                                name="mangerName"
                                disabled
                                label="商务经理"
                                initialValue="启途"
                            />
                        </ModalForm>
                    ]}
                />
            </PageContainer>

        </>

    );
};